package de.melanx.simplebackups.config;

import net.neoforged.neoforge.common.ModConfigSpec;


public class CommonConfig {

    public static final ModConfigSpec CONFIG;
    private static final ModConfigSpec.Builder BUILDER = new ModConfigSpec.Builder();

    static {
        init(BUILDER);
        CONFIG = BUILDER.build();
    }

    private static ModConfigSpec.BooleanValue enabled;
    private static ModConfigSpec.IntValue timer;
    private static ModConfigSpec.BooleanValue sendMessages;
    private static ModConfigSpec.BooleanValue noPlayerBackups;

    public static void init(ModConfigSpec.Builder builder) {
        enabled = builder.comment("If set false, no backups are being made.")
                .define("enabled", true);
        timer = builder.comment("The time between two backups in minutes", "5 = each 5 minutes", "60 = each hour", "1440 = each day")
                .defineInRange("timer", 120, 1, Short.MAX_VALUE);
        sendMessages = builder.comment("Should message be sent when backup is in the making?")
                .define("sendMessages", true);
        noPlayerBackups = builder.comment("Create backups, even if nobody is online")
                .define("noPlayerBackups", false);

        builder.push("mod_compat");
        builder.pop();
    }

    public static boolean isEnabled() {
        return enabled.get();
    }

    // converts config value from milliseconds to minutes
    public static int getTimer() {
        return timer.get() * 60 * 1000;
    }

    public static boolean doNoPlayerBackups() {
        return noPlayerBackups.get();
    }

    public static boolean sendMessages() {
        return sendMessages.get();
    }
}
